# frozen_string_literal: true

# Services entrypoint
require 'tty/prompt'

module Krb
  # syntactic sugar
  class ApplicationService
    def self.process(*args, &block)
      new(*args, &block).process
    end

    def prompt
      ::TTY::Prompt.new(interrupt: :exit)
    end

    def setup_file_name
      '.storefront_setup'
    end

    def setup_file_path
      [Dir.pwd, setup_file_name].join('/')
    end

    def verify_setup
      return if base_setup?
      ::Krb::Setup::Base.process
      remove_instance_variable(:@setup)
    end

    def verify_production
      return if production_setup?
      ::Krb::Setup::ApplyProductionNamespace.process
      remove_instance_variable(:@setup)
    end

    def verify_admin
      return if admin_setup?
      ::Krb::Setup::ApplyAdminCredentials.process
      remove_instance_variable(:@setup)
    end

    protected

    def setup
      @setup ||= begin
        if File.exist?(setup_file_path)
          JSON.parse(File.open(setup_file_path).read)
        else
          {}
        end
      end
    end

    private

    def base_setup?
      setup && !setup.dig('access_key').nil?
    end

    def production_setup?
      setup && !setup.dig('production_namespace').nil?
    end

    def admin_setup?
      setup &&
        !setup.dig('admin_api_key').nil? &&
        !setup.dig('admin_password').nil?
    end
  end
end

Dir[File.dirname(__FILE__) + '/**/*.rb'].each do |file|
  require file
end
