# frozen_string_literal: true

require 'http'

module Krb
  module Setup
    # Sets up configuration
    class AskShopifyAccessKey < ApplicationService
      def initialize(setup)
        @shop_name = setup.dig('shop_name')
      end

      def process
        if graphql_endpoint?
          input
        else
          abort("\nInvalid credentials. Please try again.\n")
          return ''
        end
      end

      private

      def input
        @input ||= prompt.mask(ask_phrase) { |q| q.required true }
      end

      def ask_phrase
        'Please enter your shopify storefront access key : '
      end

      def graphql_endpoint?
        response = HTTP.headers(graphql_headers).post(graphql_url, body: graphql_payload)
        response.code == 200
      end

      def graphql_headers
        {
          'Content-Type' => 'application/graphql',
          'X-Shopify-Storefront-Access-Token' => input
        }
      end

      def graphql_payload
        '{ shop { name } }'
      end

      def graphql_url
        "https://#{@shop_name}.myshopify.com/api/graphql"
      end
    end
  end
end
