# frozen_string_literal: true

require 'yaml'

module Krb
  module Setup
    # Sets up configuration
    class Base < ApplicationService
      def process
        shopify_prompts
        language_prompt
        wrap_up
      end

      private

      def wrap_up
        prettier_setup = JSON.pretty_generate(setup)
        File.open(setup_file_path, 'w+') { |f| f.write(prettier_setup) }
        Krb::Setup::GitIgnore.process
      end

      def shopify_prompts
        setup['shop_name'] = Krb::Setup::AskShopifyShopName.process
        setup['access_key'] = Krb::Setup::AskShopifyAccessKey.process(setup)
      end

      def language_prompt
        input = prompt.select('Select your library :', %w[php rails node])
        setup['language'] = input
      end
    end
  end
end
