# frozen_string_literal: true

module Krb
  module Setup
    # Sets up configuration
    class GitIgnore < ApplicationService
      def process
        return if has_gitignore? && is_ignored?
        add_gitignore unless has_gitignore?
        write_to_gitignore unless is_ignored?
      end

      private

      def write_to_gitignore
        open(dot_gitignore, 'a') { |f| f << "\n#{ignore_path}\n" }
      end

      def add_gitignore
        File.open(dot_gitignore, 'w+') { |f| f.write('') }
      end

      def is_ignored?
        File.readlines(dot_gitignore).grep(/#{ignore_path}/).size >= 1
      end

      def has_gitignore?
        File.exist?(dot_gitignore)
      end

      def dot_gitignore
        [Dir.pwd, '.gitignore'].join('/')
      end

      def ignore_path
        "/#{setup_file_name}"
      end
    end
  end
end
