# frozen_string_literal: true

require 'base64'

module Krb
  module Webhooks
    # Webhooks methods
    class Base < ApplicationService
      def initialize
        super
        verify_setup
        verify_production
        verify_admin
      end

      def process
        ::Krb::Webhooks::Reset.process
        %w[create update delete].each do |meth|
          HTTP.headers(headers).post(shopify_webhooks_url, body: body(meth).to_json)
        end
      end

      private

      def body(meth)
        {
          webhook: {
            topic: "products/#{meth}",
            address: "https://#{setup.dig('production_namespace')}.ngx.host/webhook",
            format: :json,
            fields: %w[handle id]
          }
        }
      end

      def shopify_webhooks_url
        "https://#{setup.dig('shop_name')}.myshopify.com/admin/webhooks.json"
      end

      def shopify_webhooks_delete_url(id)
        "https://#{setup.dig('shop_name')}.myshopify.com/admin/webhooks/#{id}.json"
      end

      def headers
        {
          'Content-Type' => 'application/json',
          'Authorization' => "Basic #{basic_auth_token}"
        }
      end

      def basic_auth_token
        Base64.strict_encode64(password)
      end

      def password
        [setup.dig('admin_api_key'), setup.dig('admin_password')].join(':')
      end
    end
  end
end
